@@ -31,33 +31,21 @@ class WebViewArtwork:
         """
         self.__helper = TaskHelper()
         self.__snapshot_id = None
+        self.__save_favicon_timeout_id = None
         self.__cancellable = Gio.Cancellable()
         self.__initial_uri = None
         self.__favicon_width = {}
-        self.__save_favicon_timeout_id = None
         self.__current_netloc = None
-
-    def set_snapshot(self):
-        """
-            Set webpage preview
-        """
-        self.stop_snapshot()
-        if not self.ephemeral and not self._error:
-            self.__snapshot_id = GLib.timeout_add(3000, self.__set_snapshot)
-
-    def stop_snapshot(self):
-        """
-            Stop pending snapshot loading
-        """
-        if self.__snapshot_id is not None:
-            GLib.source_remove(self.__snapshot_id)
-            self.__snapshot_id = None
+        self.connect("notify::uri", self.__on_uri_changed)
 
     def set_favicon(self):
         """
             Set favicon based on WebKit2 favicon database
         """
-        if self.ephemeral or self._error:
+        if self.ephemeral or\
+                self._error or\
+                self._current_event not in [WebKit2.LoadEvent.COMMITTED,
+                                            WebKit2.LoadEvent.FINISHED]:
             return
         parsed = urlparse(self.uri)
         if parsed.scheme in ["http", "https"]:
@@ -100,19 +88,14 @@ class WebViewArtwork:
             surface = App().art.get_favicon(self._uri,
                                             self.get_scale_factor())
             if surface is not None:
-                self.emit("favicon-changed", surface, None)
+                self.emit("favicon-changed", surface)
             elif self.__current_netloc is None or\
                     self.__current_netloc not in self._uri:
-                # Get symbolic favicon for icon theme
-                icon_theme_artwork = App().art.get_icon_theme_artwork(
-                    self._uri,
-                    self.ephemeral)
-                if icon_theme_artwork is not None:
-                    self.emit("favicon-changed", None, icon_theme_artwork)
-                else:
-                    self.emit("favicon-changed", None, "applications-internet")
+                self.emit("favicon-changed", None)
         elif event == WebKit2.LoadEvent.FINISHED:
-            if parsed.scheme in ["http", "https"]:
+            is_http = parsed.scheme in ["http", "https"]
+            GLib.idle_add(self.__set_snapshot, is_http)
+            if is_http:
                 favicon_database = self.context.get_favicon_database()
                 GLib.timeout_add(2000,
                                  favicon_database.get_favicon,
@@ -127,9 +110,10 @@ class WebViewArtwork:
 #######################
 # PRIVATE             #
 #######################
-    def __set_snapshot(self):
+    def __set_snapshot(self, save):
         """
             Set webpage preview
+            @param save as bool
         """
         self.__snapshot_id = None
         self.get_snapshot(WebKit2.SnapshotRegion.FULL_DOCUMENT,
@@ -137,6 +121,7 @@ class WebViewArtwork:
                           self.__cancellable,
                           get_snapshot,
                           self.__on_snapshot,
+                          save,
                           True)
 
     def __set_favicon_from_surface(self, surface, uri, initial_uri, builtin):
@@ -179,7 +164,7 @@ class WebViewArtwork:
                                                  initial_uri,
                                                  "favicon_alt")
         if resized is not None and uri == self.uri:
-            self.emit("favicon-changed", resized, None)
+            self.emit("favicon-changed", resized)
 
     def __save_favicon_to_cache(self, surface, uri, initial_uri, favicon_type):
         """
@@ -206,6 +191,15 @@ class WebViewArtwork:
                                   surface,
                                   favicon_type)
 
+    def __on_uri_changed(self, webview, param):
+        """
+            Handle JS updates
+            @param webview as WebKit2.WebView
+            @param param as GObject.ParamSpec
+        """
+        if not webview.is_loading() and not webview.ephemeral:
+            GLib.timeout_add(500, self.__set_snapshot, True)
+
     def __on_get_favicon(self, favicon_db, result, uri, initial_uri, builtin):
         """
             Read favicon and set it
@@ -221,11 +215,12 @@ class WebViewArtwork:
             surface = None
         self.__set_favicon_from_surface(surface, uri, initial_uri, builtin)
 
-    def __on_snapshot(self, surface, first_pass):
+    def __on_snapshot(self, surface, save, first_pass):
         """
             Cache snapshot
             @param surface as cairo.Surface
             @param uri as str
+            @param save as bool
             @param first_pass as bool
         """
         # The 32767 limit on the width/height dimensions
@@ -238,8 +233,12 @@ class WebViewArtwork:
                                   self.__cancellable,
                                   get_snapshot,
                                   self.__on_snapshot,
+                                  save,
                                   False)
             return
+        self.emit("snapshot-changed", surface)
+        if not save:
+            return
         uri = self.uri
         # We also cache initial URI
         uris = [uri.rstrip("/")]
